Learn R Programming

CEAmarkov (version 0.1.0)

change_current_prob_to_cycle_prob: Title This function converts the given probabilities to match the model's cycle length

Description

Title This function converts the given probabilities to match the model's cycle length

Usage

change_current_prob_to_cycle_prob(prob, year_prob, cycle_length)

Arguments

prob

probability

year_prob

current terms of the given probability in years

cycle_length

cycle length in years

Value

cycle_prob

Examples

Run this code
# NOT RUN {
drug_arm_5_years<-matrix(data = c(0,0.029,0.087*0.59,0,0,0.1,0,0.261*0.59,0,0,0,0,0,
0.325,0,0,0,0,1,0,0,0,0,0,1),nrow = 5,ncol = 5,byrow = TRUE)
drug_arm_5_years<-change_current_prob_to_cycle_prob(drug_arm_5_years,1,(1/12))
# }

Run the code above in your browser using DataLab