Learn R Programming

CEAmarkov (version 0.1.0)

covert_discount_rate: Title This function converts an annual discount rate to the proper discount rate based on the cycle length of the model

Description

Title This function converts an annual discount rate to the proper discount rate based on the cycle length of the model

Usage

covert_discount_rate(annual_discount_rate, cycle_length)

Arguments

annual_discount_rate

annual discount rate in percentages

cycle_length

cycle length in years

Value

new_discount_rate