Learn R Programming

CEAmarkov (version 0.1.0)

extract_by_age: Title This function extract the all-cause mortality probabilities using the inital age and time-horizon

Description

Title This function extract the all-cause mortality probabilities using the inital age and time-horizon

Usage

extract_by_age(initial_age, time_horizon, data_table)

Arguments

initial_age

initial age

time_horizon

null for lifetime horizon or number of years

data_table

data frame containing probabilities

Value

needed_data